@@ -9,7 +9,7 @@
 """
 
 __author__ = "Ryan McGrath <ryan@venodesigns.net>"
-__version__ = "2.3.3"
+__version__ = "2.4.0"
 
 import urllib
 import re
@@ -168,9 +168,7 @@ class Twython(object):
 
         func = getattr(self.client, method)
         if method == 'get':
-            # Still wasn't fixed in `requests` 0.13.2? :(
-            url = url + '?' + urllib.urlencode(params)
-            response = func(url)
+            response = func(url, params=params)
         else:
             response = func(url, data=params, files=files)
         content = response.content.decode('utf-8')
@@ -187,10 +185,15 @@ class Twython(object):
             'content': content,
         }
 
+
+        #  wrap the json loads in a try, and defer an error
+        #  why? twitter will return invalid json with an error code in the headers
+        json_error = False
         try:
             content = simplejson.loads(content)
         except ValueError:
-            raise TwythonError('Response was not valid JSON, unable to decode.')
+            json_error= True
+            content= {}
 
         if response.status_code > 304:
             # If there is no error message, use a default.
@@ -207,6 +210,10 @@ class Twython(object):
                                 error_code=response.status_code,
                                 retry_after=response.headers.get('retry-after'))
 
+        # if we have a json error here , then it's not an official TwitterAPI error
+        if json_error:
+            raise TwythonError('Response was not valid JSON, unable to decode.')
+
         return content
 
     '''
@@ -262,8 +269,7 @@ class Twython(object):
         if self.callback_url:
             request_args['oauth_callback'] = self.callback_url
 
-        req_url = self.request_token_url + '?' + urllib.urlencode(request_args)
-        response = self.client.get(req_url)
+        response = self.client.get(self.request_token_url, params=request_args)
 
         if response.status_code != 200:
             raise TwythonAuthError("Seems something couldn't be verified with your OAuth junk. Error: %s, Message: %s" % (response.status_code, response.content))
@@ -463,9 +469,9 @@ class Twython(object):
                             version Twitter has now
         """
         endpoint = 'users/profile_image/%s' % username
-        url = self.api_url % version + '/' + endpoint + '?' + urllib.urlencode({'size': size})
+        url = self.api_url % version + '/' + endpoint
 
-        response = self.client.get(url, allow_redirects=False)
+        response = self.client.get(url, params={'size': size}, allow_redirects=False)
         image_url = response.headers.get('location')
 
         if response.status_code in (301, 302, 303, 307) and image_url is not None:
